#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-Dz5EXulv8WxEMXcVdjhUYe
key:                  tagstream-conduit-0.5.6-Dz5EXulv8WxEMXcVdjhUYe
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  88ab5f753b2487c6511fbe8547207728
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-Dz5EXulv8WxEMXcVdjhUYe
depends:
    attoparsec-0.14.4-GTUtxC0om9b2L4ZneXqrPT base-4.18.2.1
    blaze-builder-0.4.4.1-BgmztVD7kNkBjq1RMk7arZ bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4uVw9MDvZ5oAae1xp3bqUp
    conduit-1.3.6.1-KgvxRslmDgl5Hh23ckCIr4
    conduit-extra-1.3.8-Jj0kbw13PEN4kqtz5CpH4f
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    resourcet-1.2.6-FMG404WUxrdL7VHJswAKQ6 text-2.0.2
    transformers-0.6.1.0 xml-conduit-1.9.1.4-FXBF1oDy4ja4C2iJEjAixd

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

